@@ -1,6 +1,8 @@
 function Base.copy!(Wnew::T, W::T) where {T <: AbstractNoiseProcess}
     for x in filter(!=(:u), fieldnames(typeof(W)))
-        if !ismutable(getfield(W, x))
+        if getfield(W, x) isa Random.AbstractRNG
+            setfield!(Wnew, x, copy(getfield(W, x)))
+        elseif !ismutable(getfield(W, x))
             setfield!(Wnew, x, getfield(W, x))
         elseif getfield(W, x) isa AbstractNoiseProcess
             copy!(getfield(Wnew, x), getfield(W, x))
@@ -15,14 +17,12 @@ function Base.copy!(Wnew::T, W::T) where {T <: AbstractNoiseProcess}
         elseif getfield(W, x) isa RSWM
             setfield!(getfield(Wnew, x), :discard_length, getfield(W, x).discard_length)
             setfield!(getfield(Wnew, x), :adaptivealg, getfield(W, x).adaptivealg)
-        elseif typeof(getfield(W, x)) <:
-            Union{BoxGeneration1, BoxGeneration2, BoxGeneration3}
+        elseif getfield(W, x) isa
+                Union{BoxGeneration1, BoxGeneration2, BoxGeneration3}
             setfield!(getfield(Wnew, x), :boxes, getfield(W, x).boxes)
             setfield!(getfield(Wnew, x), :probability, getfield(W, x).probability)
             setfield!(getfield(Wnew, x), :offset, getfield(W, x).offset)
             setfield!(getfield(Wnew, x), :dist, getfield(W, x).dist)
-        elseif getfield(W, x) isa Random.AbstractRNG
-            setfield!(Wnew, x, copy(getfield(W, x)))
         else
             # @warn "Got deep with $x::$(typeof(getfield(W, x))) in $(first(split(string(typeof(W)), '}')))"
             setfield!(Wnew, x, deepcopy(getfield(W, x)))
