@@ -83,13 +83,13 @@ https://math.stackexchange.com/questions/412470/conditional-distribution-in-brow
 """
 function gbm_bridge(dW, gbm, W, W0, Wh, q, h, u, p, t, rng)
     if dW isa AbstractArray
-        gbb_mean = @.. log(W0) + q * (log(W0 + Wh) - log(W0))
+        gbb_mean = @.. log(abs(W0)) + q * (log(abs(W0 + Wh)) - log(abs(W0)))
         gbb_std = sqrt((1 - q) * q * abs(h)) * gbm.σ
 
         x = gbb_mean + gbb_std * wiener_randn(rng, dW)
         return exp.(x) - W0
     else
-        gbb_mean = log(W0) + q * (log(W0 + Wh) - log(W0))
+        gbb_mean = log(abs(W0)) + q * (log(abs(W0 + Wh)) - log(abs(W0)))
         gbb_std = sqrt((1 - q) * q * abs(h)) * gbm.σ
 
         x = gbb_mean + gbb_std * wiener_randn(rng, typeof(dW))
@@ -121,7 +121,7 @@ Modifies rand_vec to contain the interpolated GBM process values
 function gbm_bridge!(rand_vec, gbm, W, W0, Wh, q, h, u, p, t, rng)
     wiener_randn!(rng, rand_vec)
     @.. rand_vec = gbm.σ * sqrt((1 - q) * q * abs(h)) * rand_vec +
-        (log(W0) + q * (log(W0 + Wh) - log(W0)))
+        (log(abs(W0)) + q * (log(abs(W0 + Wh)) - log(abs(W0))))
     return @.. rand_vec = exp(rand_vec) - W0
 end
 
