@@ -194,6 +194,7 @@ function NoiseProcess{iip}(
         reset = true, reseed = true, continuous = true,
         cache = nothing
     ) where {iip}
+    rng = rng isa Random.TaskLocalRNG ? copy(rng) : rng
     S₁ = ResettableStacks.ResettableStack{iip}(
         Tuple{
             typeof(t0), typeof(W0), typeof(Z0),
@@ -395,6 +396,7 @@ mutable struct SimpleNoiseProcess{
             rng = Random.default_rng(),
             reset = true, reseed = true
         ) where {iip}
+        rng = rng isa Random.TaskLocalRNG ? copy(rng) : rng
         if Z0 == nothing
             Z = nothing
             curZ = nothing
@@ -834,6 +836,7 @@ mutable struct NoiseTransport{T, N, wType, zType, Tt, T2, T3, TRV, Trv, RNGType,
             reset = true, reseed = true,
             noise_prototype = W(nothing, nothing, t0, rv)
         ) where {iip}
+        rng = rng isa Random.TaskLocalRNG ? copy(rng) : rng
         curt = t0
         dt = t0
         curW = copy(noise_prototype)
@@ -1158,7 +1161,7 @@ as a keyword argument. The following keyword arguments are available:
     to speed up the simulation by reducing the recursion steps.
   - `search_depth` maximal search depth for the tree if `atol` is not reached.
   - `rng` the splittable PRNG used for generating the random numbers.
-    Default: `Threefry4x()` from the Random123 package.
+    Default: `Xoshiro()` from the Random package.
 
 ## VirtualBrownianTree Example
 
@@ -1213,7 +1216,7 @@ function VirtualBrownianTree{iip}(
         tend = nothing, Wend = nothing, Zend = nothing,
         atol = 1.0e-10, tree_depth::Int = 4,
         search_depth = nothing,
-        rng = Random123.Threefry4x(),
+        rng = Xoshiro(),
         reset = true
     ) where {iip}
     if search_depth == nothing
@@ -1386,6 +1389,7 @@ function BoxWedgeTail{iip}(
         rng = Random.default_rng(),
         reset = true, reseed = true
     ) where {iip}
+    rng = rng isa Random.TaskLocalRNG ? copy(rng) : rng
     if Z0 === nothing
         Z = nothing
         curZ = nothing
