@@ -1,6 +1,5 @@
 @testset "Virtual Brownian Tree tests" begin
     using DiffEqNoiseProcess, DiffEqBase, StochasticDiffEq, Test, Random
-    import Random123
 
     W = VirtualBrownianTree(0.0, 0.0; tree_depth = 3, search_depth = 5)
     @test isinplace(W) == false
@@ -20,7 +19,7 @@
     @test_throws ErrorException accept_step!(W, dt, nothing, nothing)
 
     # test interpolation/binary search
-    rng = Random123.Threefry4x() # instantiate PRNG
+    rng = Xoshiro() # instantiate PRNG
     rngcopy = copy(rng)
     W = VirtualBrownianTree(0.0, 0.0; tree_depth = 1, search_depth = 5, rng = rng)
     t = (W.t[2] - W.t[1]) / 8
