@@ -1,5 +1,5 @@
-using StochasticDiffEq, DiffEqNoiseProcess, Test, LinearAlgebra
-using Random, Random123
+using DiffEqBase, DiffEqNoiseProcess, Test, LinearAlgebra
+using Random
 seed = 100;
 Random.seed!(seed);
 @testset "Two noise processes for different m" begin
@@ -7,20 +7,24 @@ Random.seed!(seed);
         rand_prototype = zeros(m)
         rand_prototype2 = similar(rand_prototype, Int(m * (m - 1) / 2))
         rand_prototype2 .= false
-        Random.seed!(seed)
+
+        rng_base = Xoshiro()
+        Random.seed!(rng_base)
+        rng1 = copy(rng_base)
+        rng2 = copy(rng_base)
+
         W = WienerProcess!(
-            0.0, rand_prototype, rand_prototype2,
+            0.0, copy(rand_prototype), copy(rand_prototype2),
             save_everystep = true,
-            rng = Random123.Threefry4x()
+            rng = rng1, reseed = false
         )
         prob = NoiseProblem(W, (0.0, 1.0))
         sol = solve(prob; dt = 0.2)
 
-        Random.seed!(seed)
         Woop = WienerProcess(
-            0.0, rand_prototype, rand_prototype2,
+            0.0, copy(rand_prototype), copy(rand_prototype2),
             save_everystep = true,
-            rng = Random123.Threefry4x()
+            rng = rng2, reseed = false
         )
         proboop = NoiseProblem(Woop, (0.0, 1.0))
         soloop = solve(proboop; dt = 0.2)
